@@ -1,5 +1,5 @@
-# Gufw 17.10.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 19.10.0 - http://gufw.org
+# Copyright (C) 2008-2019 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -475,7 +475,7 @@ class Backend():
         ips = cmd.split('\n')
         
         if len(ips) > 0:
-            return ips[0]
+            return ips[0].strip()
         else:
             return '127.0.0.1'
     
