@@ -1,5 +1,5 @@
-# Gufw 17.10.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 19.10.0 - http://gufw.org
+# Copyright (C) 2008-2019 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -96,9 +96,11 @@ class Add:
         
         self.advanced_policy.set_active(0)
         self.advanced_direction.set_active(0)
+        # Translators: About the network interfaces in the OS
         self.advanced_iface.append_text(_("All Interfaces"))
+        # Translators: About traffic
         self.advanced_routed.append_text(_("Not Forward"))
-        for ifaceName in self.gufw.fw.get_net_interfaces():
+        for ifaceName in self.gufw.frontend.get_net_interfaces():
             self.advanced_iface.append_text(ifaceName)
             self.advanced_routed.append_text(ifaceName)
         self.advanced_iface.set_active(0)
@@ -106,7 +108,7 @@ class Add:
         self.advanced_log.set_active(0)
         self.advanced_protocol.set_active(0)
         
-        if self.gufw.fw.get_policy('routed') == 'disabled':
+        if self.gufw.frontend.get_policy('routed') == 'disabled':
             self.advanced_routed_img.set_visible(False)
             self.advanced_routed.set_visible(False)
     
@@ -136,6 +138,7 @@ class Add:
         for cat in categories:
             self.preconfig_category.append_text(cat)
         try:
+            # Translators: ALL applications
             self.preconfig_category.set_active(categories.index(_("All")))
         except Exception:
             self.preconfig_category.set_active(0)
@@ -161,16 +164,16 @@ class Add:
         return True # Overwrite event
     
     def _win_close(self):
-        self.gufw.show_add_btn.set_sensitive(self.gufw.fw.get_status())
-        self.gufw.edit_rule_btn.set_sensitive(self.gufw.fw.get_status())
-        self.gufw.report_rule_btn.set_sensitive(self.gufw.fw.get_status())
+        self.gufw.show_add_btn.set_sensitive(self.gufw.frontend.get_status())
+        self.gufw.edit_rule_btn.set_sensitive(self.gufw.frontend.get_status())
+        self.gufw.report_rule_btn.set_sensitive(self.gufw.frontend.get_status())
         self._hide_win()
     
     def on_copy_from_IP_clicked(self, widget, data=None):
-        self.advanced_from_ip.set_text(self.gufw.fw.get_internal_ip())
+        self.advanced_from_ip.set_text(self.gufw.frontend.get_internal_ip())
     
     def on_copy_to_IP_clicked(self, widget, data=None):
-        self.advanced_to_ip.set_text(self.gufw.fw.get_internal_ip())
+        self.advanced_to_ip.set_text(self.gufw.frontend.get_internal_ip())
     
     def on_copy_simple_to_advanced_clicked(self, widget, data=None):
         self.advanced_rule_name.set_text(self.simple_rule_name.get_text())
@@ -265,6 +268,7 @@ class Add:
         for subcat in subcategories:
             self.preconfig_subcategory.append_text(subcat)
         # Append new apps
+        # Translators: ALL applications
         apps = self.apps.get_apps_cat_subcat(self.preconfig_category.get_active_text(), _("All"))
         for app in apps:
             self.preconfig_app.append_text(app)
@@ -346,6 +350,7 @@ class Add:
         self.advanced_to_port.set_text('')
     
     def on_advanced_iface_changed(self, widget, data=None, data2=None):
+        # Translators: About the network interfaces in the OS
         if self.advanced_iface.get_active_text() != _("All Interfaces"):
             self.advanced_routed.set_sensitive(True)
             self.advanced_routed.set_tooltip_text(_("The IP/Port will be forward to this interface"))
@@ -354,10 +359,11 @@ class Add:
             self.advanced_routed.set_tooltip_text(_("You need to set an Interface for forwarding to this another interface"))
         
         # Not allow same iface when is routed
-        if self.gufw.fw.get_policy('routed') != 'disabled':
+        if self.gufw.frontend.get_policy('routed') != 'disabled':
             self.advanced_routed.remove_all()
+            # Translators: About traffic
             self.advanced_routed.append_text(_("Not Forward"))
-            for ifaceName in self.gufw.fw.get_net_interfaces(self.advanced_iface.get_active_text()):
+            for ifaceName in self.gufw.frontend.get_net_interfaces(self.advanced_iface.get_active_text()):
                 self.advanced_routed.append_text(ifaceName)
             self.advanced_routed.set_active(0)
     
@@ -372,7 +378,7 @@ class Add:
                 self.warningbox.hide()
     
     def on_btnAddRuleWin_clicked(self, widget, data=None):
-        if not self.gufw.fw.get_status():
+        if not self.gufw.frontend.get_status():
             self.gufw.show_dialog(self.win_add, _("Error: Firewall is disabled"), _("The firewall has to be enabled first"))
             return
         
@@ -393,10 +399,10 @@ class Add:
                 from_port = from_split
                 to_port = to_split
                 if direction == 'both':
-                    cmd = self.gufw.fw.add_rule(name, insert, policy, 'in',  iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
-                    cmd = self.gufw.fw.add_rule(name, insert, policy, 'out', iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
+                    cmd = self.gufw.frontend.add_rule(name, insert, policy, 'in',  iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
+                    cmd = self.gufw.frontend.add_rule(name, insert, policy, 'out', iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
                 else:
-                    cmd = self.gufw.fw.add_rule(name, insert, policy, direction, iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
+                    cmd = self.gufw.frontend.add_rule(name, insert, policy, direction, iface, routed, logging, proto, from_ip, from_port, to_ip, to_port)
                 
                 if cmd[0]:
                     flag_Warning = True
@@ -416,7 +422,7 @@ class Add:
             self.gufw.set_statusbar_msg(_("Error: No rules added. Review the log"))
     
     def _add_rule_preconfig(self):
-        self._add(self.gufw.fw.get_profile(),                                    # profile
+        self._add(self.gufw.frontend.get_profile(),                                    # profile
                  self.preconfig_app.get_active_text(),                           # name
                  self.gufw.NUM2POLICY[self.preconfig_policy.get_active()],       # policy
                  self.gufw.NUM2DIRECTION[self.preconfig_direction.get_active()], # direction
@@ -425,7 +431,7 @@ class Add:
                  '',                                                             # from port
                  '',                                                             # to IP
                  self.apps.get_app(self.preconfig_app.get_active_text())[1])     # to port[/proto][|port[/proto]]
-        self.gufw.print_rules(self.gufw.fw.get_rules())
+        self.gufw.print_rules(self.gufw.frontend.get_rules())
     
     def _add_rule_simple(self):
         if not self.simple_port.get_text():
@@ -436,7 +442,7 @@ class Add:
             self.gufw.show_dialog(self.win_add, _("Edward Snowden's Greatest Fear"), _('"Nothing Will Change"'))
             return
         
-        self._add(self.gufw.fw.get_profile(),                                 # profile
+        self._add(self.gufw.frontend.get_profile(),                                 # profile
                  self.simple_rule_name.get_text(),                            # name
                  self.gufw.NUM2POLICY[self.simple_policy.get_active()],       # policy
                  self.gufw.NUM2DIRECTION[self.simple_direction.get_active()], # direction
@@ -445,7 +451,7 @@ class Add:
                  '',                                                          # from port
                  '',                                                          # to IP
                  self.simple_port.get_text())                                 # to port
-        self.gufw.print_rules(self.gufw.fw.get_rules())
+        self.gufw.print_rules(self.gufw.frontend.get_rules())
     
     def _add_rule_advanced(self):
         # Validations
@@ -457,10 +463,12 @@ class Add:
             insert = ''
         
         iface = ''
+        # Translators: About traffic
         if self.advanced_iface.get_sensitive() and self.advanced_iface.get_active_text() != _("All Interfaces"):
             iface = self.advanced_iface.get_active_text()
         
         routed = ''
+        # Translators: About traffic
         if self.advanced_routed.get_sensitive() and self.advanced_routed.get_active_text() != _("Not Forward"):
             routed = self.advanced_routed.get_active_text()
         
@@ -470,7 +478,7 @@ class Add:
         to_ip = self.advanced_to_ip.get_text()
         to_port = self.advanced_to_port.get_text()
         
-        self._add(self.gufw.fw.get_profile(),                                   # profile
+        self._add(self.gufw.frontend.get_profile(),                                   # profile
                  self.advanced_rule_name.get_text(),                            # name
                  self.gufw.NUM2POLICY[self.advanced_policy.get_active()],       # policy
                  self.gufw.NUM2DIRECTION[self.advanced_direction.get_active()], # direction
@@ -483,7 +491,7 @@ class Add:
                  iface,                                                         # interface
                  routed,                                                        # routed
                  self.gufw.NUM2LOGGING[self.advanced_log.get_active()])         # logging        
-        self.gufw.print_rules(self.gufw.fw.get_rules())
+        self.gufw.print_rules(self.gufw.frontend.get_rules())
 
 
 class AppProfiles:
@@ -535,6 +543,7 @@ class AppProfiles:
             if not categ.count(current_cat):
                 categ.append(current_cat)
         categ.sort()
+        # Translators: About categories
         categ.insert(0, _("All"))
         return categ
     
@@ -542,6 +551,7 @@ class AppProfiles:
         subcateg = []
         for cat in self.all_categories:
             current_cat = cat.split(';')[0]
+            # Translators: About categories
             if current_cat == category or category == _("All"):
                 try:
                     current_subcat = cat.split(';')[1]
@@ -550,6 +560,7 @@ class AppProfiles:
                 if not subcateg.count(current_subcat) and current_subcat:
                     subcateg.append(current_subcat)
         subcateg.sort()
+        # Translators: About subcategories
         subcateg.insert(0, _("All"))
         return subcateg
     
@@ -564,10 +575,14 @@ class AppProfiles:
                 except Exception:
                     current_subcat = ''
                 
+                # Translators: About categories
+                # Translators: About subcategories
                 if cat == _("All") and subcat == _("All"):
                     apps.append(app)
+                # Translators: About categories
                 elif cat == _("All") and subcat == current_subcat:
                     apps.append(app)
+                # Translators: About categories
                 elif cat == current_cat and subcat == _("All"):
                     apps.append(app)
                 elif cat == current_cat and subcat == current_subcat:
