@@ -1,5 +1,5 @@
-# Gufw 18.10.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 19.10.0 - http://gufw.org
+# Copyright (C) 2008-2019 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@ class ListeningReport():
         
         self._show_report()
         
-        if self.gufw.fw.get_config_value('RefreshInterval'):
-            time = int(self.gufw.fw.get_config_value('RefreshInterval'))
+        if self.gufw.frontend.get_config_value('RefreshInterval'):
+            time = int(self.gufw.frontend.get_config_value('RefreshInterval'))
         else:
             time = REFRESH_TIME
         GLib.timeout_add((time * 1000), self._show_report)
@@ -44,7 +44,7 @@ class ListeningReport():
         if not self.running_listening:
             return False
         
-        report = self.gufw.fw.get_listening_report()
+        report = self.gufw.frontend.get_listening_report()
         self._view_report(report, self.previous_report)
         self.previous_report = report
         
@@ -85,7 +85,7 @@ class ListeningReport():
             self.gufw.listening_model.set_value(iter_row, 3, line_split[3].strip()) # app
             self.gufw.listening_model.set_value(iter_row, 5, row)                    # number
             
-            if self.gufw.fw.get_status():
+            if self.gufw.frontend.get_status():
                 if line_split[4] == 'allow':
                     self.gufw.listening_model.set_value(iter_row, 4, self.gufw.RED)
                 elif line_split[4] == 'deny':
